@@ -1,8 +1,10 @@
 package Pcore::Util::Random;
 
-use Pcore -export => { ALL => [qw[random_bytes random_bytes_hex]] };
+use Pcore -export;
 use Net::SSLeay qw[];
 
+our $EXPORT = { ALL => [qw[random_bytes random_bytes_hex]] };
+
 our $PASSWORD_LENGTH = 16;
 
 my $PASSWORD_SYMBOLS = [ 0 .. 9, 'a' .. 'z', 'A' .. 'Z', qw[! @ $ % ^ & *], q[#] ];
